import { ApiAction, ApiActionPage } from '../../model/baseModel';
import { Api, genAction, genActionPage } from '../system';
import { defHttp } from '/@/utils/http/axios';
import { MES_ROUTE, MES_ROUTE_NODE_POST, RouteData, V_MES_ROUTE_PTREE, V_MES_WO_PTREE } from '../model/router';
import { mesApi } from './mesApi';
import { useUserStore } from '/@/store/modules/user';
import { DelProdRotInput, DelWoRotInput, ProdRotInput, RoutePageListGetResultModel, RoutelistPageParams, WoRotInput } from '../model/mesModel';
import { buildUUID } from '/@/utils/uuid';

/**
 * @description: 获取工艺路线列表
 * @param {string} route_code
 * @return {*}
 */
export function getRouteData(route_code: string) {
  const params = genAction('', route_code);
  return getApi(params);
}
async function getApi(params: ApiAction<string>) {
  const data = await defHttp.post<ApiAction<RouteData>>(
    {
      url: mesApi.GetRouteData,
      params,
    },
    {
      errorMessageMode: 'modal',
      isTransformResponse: false,
    },
  );
  return data;
}

/**
 * @description: 获取工单工艺路线列表
 * @param {string} route_code
 * @return {*}
 */
export function getWoRouteData(route_code: string) {
  const params = genAction('', route_code);
  return getWoRotApi(params);
}
async function getWoRotApi(params: ApiAction<string>) {
  const data = await defHttp.post<ApiAction<RouteData>>(
    {
      url: mesApi.GetWoRouteData,
      params,
    },
    {
      errorMessageMode: 'modal',
      isTransformResponse: false,
    },
  );
  return data;
}

/**
 * @description: 保存工艺路线
 * @param {RouteData} params
 * @return {*}
 */
export const SaveRouteData = async (params: RouteData) => {
  const data = await defHttp.post(
    { url: mesApi.SaveRouteData, params: genAction('', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 保存工单工艺路线
 * @param {RouteData} params
 * @return {*}
 */
export const SaveWoRouteData = async (params: RouteData) => {
  const data = await defHttp.post(
    { url: mesApi.SaveWoRouteData, params: genAction('', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

export const SaveRoute = async (params: MES_ROUTE) => {
  params.CREATE_USER = useUserStore().getUserInfo.userId as string;
  params.UPDATE_USER = useUserStore().getUserInfo.userId as string;
  params.AUTH_ORG = useUserStore().getUserInfo.orgCode as string;
  const data = await defHttp.post(
    { url: mesApi.SaveRoute, params: genAction('MES_ROUTE', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/*
 * 获取工艺路线分页列表
 */
export const getRouteListByPage = async (params: RoutelistPageParams) => {
  let sqlcmd = '';
  if (params?.IS_ACTIVE != undefined && params?.IS_ACTIVE != '') {
    sqlcmd += " And IS_ACTIVE = '" + params?.IS_ACTIVE + "'";
  }
  if (params?.ROT_CODE != undefined && params?.ROT_CODE != '') {
    sqlcmd += "And ROT_CODE like '%" + params?.ROT_CODE + "%'";
  }
  if (params?.ROT_NAME != undefined && params?.ROT_NAME != '') {
    sqlcmd += "And ROT_NAME like '%" + params?.ROT_NAME + "%'";
  }
  const rParams = genActionPage('MES_ROUTE', sqlcmd, params.page, params.pageSize);
  return getRoleListByPageAsync(rParams);
};
async function getRoleListByPageAsync(params: ApiActionPage) {
  const data = await defHttp.post<ApiActionPage>(
    { url: Api.EntityPageList, params },
    {
      isTransformResponse: false,
    },
  );
  const model: RoutePageListGetResultModel = {
    items: data.Data.data,
    total: data.Data.totals,
  };
  return model;
}

/*
 * 删除工艺路线 
 */
export const DeleteRoute = async (params: string) => {
  const usParams = genAction('MES_ROUTE', params);
  return await defHttp.post(
    { url: mesApi.DeleteRoute, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};

/**
 * @description: 删除工单绑定的工艺路线
 * @param {string} params
 * @return {*}
 */
export const DeleteWoRoute = async (params: DelWoRotInput) => {
  const usParams = genAction('', params);
  return await defHttp.post(
    { url: mesApi.DeleteWoRoute, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};

/**
 * @description: 删除产品绑定的工艺路线
 * @param {string} params
 * @return {*}
 */
export const DeleteProdRoute = async (params: DelProdRotInput) => {
  const usParams = genAction('', params);
  return await defHttp.post(
    { url: mesApi.DeleteProdRoute, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};

export const setRouteStatus = (params: MES_ROUTE) =>
  defHttp.post(
    { url: Api.UpdateEntity, params: genAction('MES_ROUTE', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );

/**
 * @description: 保存工艺路线的岗位资源
 * @param {MES_ROUTE_NODE_POST} params
 * @return {*}
 */  
export const SaveRouteNodePost = async (params: MES_ROUTE_NODE_POST[]) => {
  const data = await defHttp.post(
    { url: mesApi.SaveRouteNodePost, params: genAction('MES_ROUTE_NODE_POST', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 保存工单工艺路线的岗位资源
 * @param {MES_ROUTE_NODE_POST} params
 * @return {*}
 */  
export const SaveWoRouteNodePost = async (params: MES_ROUTE_NODE_POST[]) => {
  const data = await defHttp.post(
    { url: mesApi.SaveWoRouteNodePost, params: genAction('MES_WO_NODE_POST', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 保存默认工艺路线到产品
 * @param {ProdRotInput} params
 * @return {*}
 */
export const SetDefaultRoute = async (params: ProdRotInput) => {
  const data = await defHttp.post(
    { url: mesApi.SetDefaultRoute, params: genAction('', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 获取产品工艺路线树形数据
 * @param {string} params
 * @return {*}
 */
export async function GetRoutePTree(params: {}) {
  const data = await defHttp.get<V_MES_ROUTE_PTREE[]>(
    {
      url: mesApi.GetRoutePTree,
      params: params,
    },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
}

/**
 * @description: 获取工单工艺路线树形数据
 * @param {string} params
 * @return {*}
 */
export async function GetWoPTree(params: {}) {
  const data = await defHttp.get<V_MES_WO_PTREE[]>(
    {
      url: mesApi.GetWoPTree,
      params: params,
    },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
}

/**
 * @description: 添加工艺线到产品
 * @param {*} params
 * @return {*}
 */
export const RouteToProd = async (params: {}) => {
  const data = await defHttp.get(
    { url: mesApi.RouteToProd, params: params },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 添加工艺线到客户
 * @param {*} params
 * @return {*}
 */
export const RouteToCust = async (params: {}) => {
  const data = await defHttp.get(
    { url: mesApi.RouteToCust, params: params },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 添加工艺线到工单
 * @param {*} params
 * @return {*}
 */
export const ProdRouteToWo = async (params: WoRotInput) => {
  const data = await defHttp.post(
    { url: mesApi.ProdRouteToWo, params: genAction('', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/**
 * @description: 添加工艺线到工单的客户
 * @param {*} params
 * @return {*}
 */
export const SP_MES_WO2CUST = async (params: {}) => {
  const data = await defHttp.get(
    { url: mesApi.SP_MES_WO2CUST, params: params },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};
